@@ -7,11 +7,13 @@ from airflow_commons.resources.bigquery import (
     ARCHIVE_SOURCE_STATEMENT_FILE,
     ARCHIVE_DELETE_WHERE_STATEMENT_FILE,
 )
-from airflow_commons.internal.bigquery.bigquery_utils import (
-    DEFAULT_TIMEOUT,
-    DEFAULT_LOCATION,
-    DEFAULT_RETURN_TYPE,
-    connect,
+from airflow_commons.internal.bigquery.auth import connect
+from airflow_commons.internal.bigquery.defaults import (
+    TIMEOUT,
+    LOCATION,
+    SELECT_RETURN_TYPE,
+)
+from airflow_commons.internal.bigquery.core import (
     get_time_partition_field,
     single_value_select,
     query,
@@ -21,14 +23,14 @@ from airflow_commons.internal.bigquery.bigquery_utils import (
     get_primitive_column_list,
     get_job_config,
 )
-from airflow_commons.internal.bigquery.sql_utils import (
+from airflow_commons.internal.bigquery.query import (
     get_deduplication_source_statement,
     get_merge_sql,
     get_delete_sql,
     get_deduplication_additional_merge_conditions,
 )
-from airflow_commons.internal.file_utils import read_sql
-from airflow_commons.internal.time_utils import get_buffered_timestamp
+from airflow_commons.internal.util.file_utils import read_sql
+from airflow_commons.internal.util.time_utils import get_buffered_timestamp
 
 ARCHIVE_MODES = ["INSERT", "UPSERT"]
 DEFAULT_PRIMARY_KEYS = ["id"]
@@ -50,8 +52,8 @@ def deduplicate(
     time_columns=None,
     allow_partition_pruning: bool = True,
     job_priority: str = None,
-    timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_LOCATION,
+    timeout=TIMEOUT,
+    location=LOCATION,
 ):
     """
     Runs a merge query to deduplicate rows in historic table, and write to target snapshot table
@@ -156,8 +158,8 @@ def upsert(
     primary_keys=None,
     additional_merge_conditions: str = None,
     job_priority: str = None,
-    timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_LOCATION,
+    timeout=TIMEOUT,
+    location=LOCATION,
 ):
     """
     Runs a merge query to upsert target table, with given source statement, merge conditions, and primary keys
@@ -214,8 +216,8 @@ def insert(
     primary_keys=None,
     additional_merge_conditions: str = None,
     job_priority: str = None,
-    timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_LOCATION,
+    timeout=TIMEOUT,
+    location=LOCATION,
 ):
     """
     Runs a merge query to insert non-existing rows to target table, with given source statement, merge conditions, and primary keys
@@ -301,10 +303,10 @@ def write_query_results_to_destination(
 def get_query_results(
     service_account_file: str,
     sql_file: str,
-    return_type: str = DEFAULT_RETURN_TYPE,
+    return_type: str = SELECT_RETURN_TYPE,
     sql_params: dict = None,
-    timeout: int = DEFAULT_TIMEOUT,
-    location: str = DEFAULT_LOCATION,
+    timeout: int = TIMEOUT,
+    location: str = LOCATION,
     index_label: str = None,
     job_priority: str = None,
 ):
@@ -341,8 +343,8 @@ def get_single_value_query_results(
     sql_file: str,
     sql_params: dict = None,
     job_priority: str = None,
-    timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_LOCATION,
+    timeout=TIMEOUT,
+    location=LOCATION,
 ):
     """
     Runs a single value returning query and returns the result
@@ -376,8 +378,8 @@ def delete(
     where_statement_file: str,
     where_statement_params: dict = None,
     job_priority: str = None,
-    timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_LOCATION,
+    timeout=TIMEOUT,
+    location=LOCATION,
 ):
     """
     Runs a delete query on given table, and removes rows that conform where condition
@@ -425,8 +427,8 @@ def archive(
     primary_keys: list = None,
     mode: str = "INSERT",
     job_priority: str = None,
-    timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_LOCATION,
+    timeout=TIMEOUT,
+    location=LOCATION,
 ):
     """
     Archives selected rows on target non-partitioned table.
